@@ -203,7 +203,11 @@ nautilus_directory_finalize (GObject *object)
 	if (directory->details->dequeue_pending_idle_id != 0) {
 		g_source_remove (directory->details->dequeue_pending_idle_id);
 	}
- 
+
+	if (directory->details->call_ready_idle_id != 0) {
+		g_source_remove (directory->details->call_ready_idle_id);
+	}
+	
 	g_free (directory->details->uri);
 
 	if (directory->details->vfs_uri != NULL) {
@@ -262,9 +266,10 @@ emit_change_signals_for_all_files (NautilusDirectory *directory)
 		files = g_list_prepend (files, directory->details->as_file);
 	}
 
+	nautilus_file_list_ref (files);
 	nautilus_directory_emit_change_signals (directory, files);
 
-	g_list_free (files);
+	nautilus_file_list_free (files);
 }
 
 static void
@@ -1664,7 +1669,11 @@ is_tentative (gpointer data, gpointer callback_data)
 	g_assert (callback_data == NULL);
 
 	file = NAUTILUS_FILE (data);
-	return file->details->info == NULL;
+	/* Avoid returning files with !is_added, because these
+	 * will later be sent with the files_added signal, and a
+	 * user doing get_file_list + files_added monitoring will
+	 * then see the file twice */
+	return file->details->info == NULL || !file->details->is_added;
 }
 
 GList *
