@@ -37,11 +37,12 @@ typedef void (* NautilusNewFolderCallback) (const char *new_folder_uri,
 					    gpointer    callback_data);
 typedef void (* NautilusNewFileCallback)   (const char *new_file_uri,
 					    gpointer    callback_data);
+typedef void (* NautilusSetPermissionsCallback) (gpointer    callback_data);
 
 /* FIXME: int copy_action should be an enum */
 
 void nautilus_file_operations_copy_move   (const GList               *item_uris,
-					   GArray                    *target_item_points,
+					   GArray                    *relative_item_points,
 					   const char                *target_dir_uri,
 					   GdkDragAction              copy_action,
 					   GtkWidget                 *parent_view,
@@ -49,15 +50,18 @@ void nautilus_file_operations_copy_move   (const GList               *item_uris,
 					   gpointer                   done_callback_data);
 void nautilus_file_operations_empty_trash (GtkWidget                 *parent_view);
 void nautilus_file_operations_new_folder  (GtkWidget                 *parent_view,
+					   GdkPoint                  *target_point,
 					   const char                *parent_dir_uri,
 					   NautilusNewFolderCallback  done_callback,
 					   gpointer                   done_callback_data);
 void nautilus_file_operations_new_file    (GtkWidget                 *parent_view,
+					   GdkPoint                  *target_point,
 					   const char                *parent_dir,
 					   const char                *initial_contents,
 					   NautilusNewFileCallback    done_callback,
 					   gpointer                   data);
 void nautilus_file_operations_new_file_from_template (GtkWidget               *parent_view,
+					   	      GdkPoint                *target_point,
 						      const char              *parent_dir,
 						      const char              *target_filename,
 						      const char              *template_uri,
@@ -67,5 +71,12 @@ void nautilus_file_operations_new_file_from_template (GtkWidget               *p
 void nautilus_file_operations_delete      (const GList               *item_uris,
 					   GtkWidget                 *parent_view);
 
+void nautilus_file_set_permissions_recursive (const char                     *directory,
+					      GnomeVFSFilePermissions         file_permissions,
+					      GnomeVFSFilePermissions         file_mask,
+					      GnomeVFSFilePermissions         folder_permissions,
+					      GnomeVFSFilePermissions         folder_mask,
+					      NautilusSetPermissionsCallback  callback,
+					      gpointer                        callback_data);
 
 #endif /* NAUTILUS_FILE_OPERATIONS_H */
