@@ -51,8 +51,7 @@ typedef void (* NautilusIconCallback) (NautilusIconData *icon_data,
 typedef struct {
 	int x;
 	int y;
-	double scale_x;
-	double scale_y;
+	double scale;
 } NautilusIconPosition;
 
 typedef enum {
@@ -94,24 +93,27 @@ typedef struct {
 	void         (* context_click_selection)  (NautilusIconContainer *container,
 						   GdkEventButton *event);
 	void	     (* move_copy_items)	  (NautilusIconContainer *container,
-						   GList *item_uris,
+						   const GList *item_uris,
 						   GdkPoint *relative_item_points,
 						   const char *target_uri,
 						   GdkDragAction action,
 						   int x,
 						   int y);
-	void	     (* handle_url)		  (NautilusIconContainer *container,
-						   char *url,
+	void	     (* handle_netscape_url)	  (NautilusIconContainer *container,
+						   const char *url,
+						   const char *target_uri,
 						   GdkDragAction action,
 						   int x,
 						   int y);
 	void	     (* handle_uri_list)    	  (NautilusIconContainer *container,
-						   char *uri_list,
+						   const char *uri_list,
+						   const char *target_uri,
 						   GdkDragAction action,
 						   int x,
 						   int y);
 	void	     (* handle_text)		  (NautilusIconContainer *container,
-						   char *text,
+						   const char *text,
+						   const char *target_uri,
 						   GdkDragAction action,
 						   int x,
 						   int y);
@@ -226,6 +228,8 @@ void              nautilus_icon_container_scroll_to_icon                (Nautilu
 									 NautilusIconData       *data);
 
 /* control the layout */
+void              nautilus_icon_container_set_is_reloading              (NautilusIconContainer  *container,
+									 gboolean                is_reloading);
 gboolean          nautilus_icon_container_is_auto_layout                (NautilusIconContainer  *container);
 void              nautilus_icon_container_set_auto_layout               (NautilusIconContainer  *container,
 									 gboolean                auto_layout);
