@@ -42,7 +42,7 @@
 #include <fcntl.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtkcheckmenuitem.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libnautilus-private/nautilus-desktop-icon-file.h>
