@@ -1168,8 +1168,8 @@ create_popup_menu (FMTreeView *view)
 	eel_gtk_menu_append_separator (GTK_MENU (popup));
 	
 	/* add the "move to trash" menu item */
-	menu_image = gtk_image_new_from_stock (GTK_STOCK_DELETE,
-					       GTK_ICON_SIZE_MENU);
+	menu_image = gtk_image_new_from_icon_name ("user-trash",
+						   GTK_ICON_SIZE_MENU);
 	gtk_widget_show (menu_image);
 	menu_item = gtk_image_menu_item_new_with_label (_("Move to Trash"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
